APP_DEVICE_ID = '3C861A5820190429'
SDK_VER = '3.9'
APP_UA = 'APP/com.xiaomi.mihome APPV/6.0.103 iosPassportSDK/3.9.0 iOS/14.4 miHSTS'
MINA_UA = 'MiHome/6.0.103 (com.xiaomi.mihome; build:6.0.103.1; iOS 14.4.0) Alamofire/6.0.103 MICO/iOSApp/appStore/6.0.103'
MIIO_UA = 'iOS-14.4-6.0.103-iPhone12,3--D7744744F7AF32F0544445285880DD63E47D9BE9-8816080-84A3F44E137B71AE-iPhone'


class API:
    MIIO = 'https://api.io.mi.com/app'
    USBS = 'https://api2.mina.mi.com/remote/ubus'
    SERVICE_AUTH = 'https://account.xiaomi.com/pass/serviceLoginAuth2'
    SERVICE_LOGIN = 'https://account.xiaomi.com/pass/serviceLogin'
    PLAYLIST = 'https://api2.mina.mi.com/music/playlist/v2/lists'
    PLAYLIST_SONGS = 'https://api2.mina.mi.com/music/playlist/v2/songs'
    SONG_INFO = 'https://api2.mina.mi.com/music/song_info'
    DEVICE_LIST = 'https://api2.mina.mi.com/admin/v2/device_list'
